require 'oauth'
require 'json'
require 'yaml'

module Grubber
  class Client

    HOST = 'api.yelp.com'
    attr_accessor :consumer_key, :consumer_secret, :token_key, :token_secret

    def search(term, opts={})
      lat, lng = *Grubber::CONFIG.coordinates
      yelp     = connection
      return [] if yelp.nil?

      response = yelp.get("/v2/search?term=#{term}&ll=#{lat},#{lng}")
      Restaurant.parse(response.body)
    end

    private

    def connection
      return @connection if defined?(@connection)
      ckey, csec, tkey, tsec = credentials
      
      oauth = OAuth::Consumer.new(ckey, csec, {:site => "http://#{HOST}"})
      @connection = OAuth::AccessToken.new(oauth, tkey, tsec)
    end

    def credentials
      config = Grubber::CONFIG
      unless config.has_auth?
        puts "\nYou are missing Yelp API Credentials"
        puts "Add your credentials using `grubber auth`"
        return nil
      end

      return [
        config.consumer_key,
        config.consumer_secret,
        config.token_key,
        config.token_secret
      ]
    end

  end
end
