require 'lost'

module Grubber
  class Config

    attr_accessor :store, :lat, :lng, :credentials

    def initialize(opts={})
      @store = Grubber::Store.load[:grubber]

      location = store[:location]
      @lat = location[:lat]
      @lng = location[:lng]
      
      @credentials = store[:credentials]
      self
    end

    def self.load
      new
    end
    
    def coordinates
      [lat, lng]
    end

    def has_auth?
      !self.credentials.nil?
    end

    # consumer_key, consumer_secret
    # token_key,    token_secret
    %w(consumer token).each do |type|
      %w(key secret).each do |obj|
        auth_attr = "#{type}_#{obj}".to_sym
        define_method(auth_attr) do
          return '' unless has_auth?
          credentials[auth_attr] || ''
        end
      end
    end

    def self.update_auth(ckey, csec, tkey, tsec)
      [ckey, csec, tkey, tsec].each do |k|
        return nil if k.nil? || k == ''
      end

      Grubber::Store.update({
        credentials: {
          consumer_key: ckey,
          consumer_secret: csec,
          token_key: tkey,
          token_secret: tsec
        }
      })
    end

    def self.update_location
      lat, lng = *Lost.current_position
      Grubber::Store.update({
        location: {
          lat: lat,
          lng: lng
        }
      })
      return [lat, lng]
    end

  end
end
