require 'yaml'
require 'lost'

module Grubber
  class Store

    attr_accessor :path, :content

    DEFAULT_PATH = "/Users/#{`whoami`.strip}/.grubber"

    def initialize(opts={})
      @path = opts[:path] || DEFAULT_PATH
      
      setup
    end

    def self.load
      client = new

      data = client.read
      return data unless data.nil?

      client.reset
    end

    def self.update(data)
      return unless data.is_a?(Hash)
      
      client = new
      client.content[:grubber].merge!(data)
      client.write
      data
    end

    def setup
      return reload if File.exist?(path)

      reset
    end

    def read
      begin
        yml = YAML.load_file(path)
      rescue TypeError => e
        return nil
      end
      
      return nil unless yml

      yml
    end

    def reload
      @content = read
    end

    def write
      File.open(path, 'w'){|f| f.write(content.to_yaml) }
    end

    def reset
      File.open(path, 'w') do |f|
        f.write(base_config.to_yaml)
      end

      reload
    end

    def base_config
      lat, lng      = *Lost.current_position
      current_time  = Time.now.to_i

      { 
        grubber: {
          location: {
            lat: lat,
            lng: lng  
          },
          created_at: current_time
        }
      }
    end

  end
end
